module CushionDefaults
  # Raised when a program attempts to overwrite a frozen default value.
  class FrozenDefaultError < RuntimeError
    # @return [Class] whose frozen default {#frozen_default_name} the program tried to override
    attr_reader :originating_class
    # @return [symbol] the frozen default in {#originating_class} that the program attempted to override
    attr_reader :frozen_default_name

    def initialize(orignating_class, frozen_default_name)
      @originating_class = orignating_class
      @frozen_default_name = frozen_default_name
    end

    # Include {#originating_class} and {#frozen_default_name} in #to_s
    # @return [String]
    def to_s
      "#{@originating_class}.defaults[:#{@frozen_default_name} is frozen!"
    end
  end
end